@@ -1,5 +1,4 @@
 import asyncio
-import logging
 from datetime import datetime
 from typing import Any, AsyncIterator, Callable, Dict, List, Optional, Set, Tuple, Union
 
@@ -7,8 +6,6 @@ from airflow.triggers.base import BaseTrigger, TriggerEvent
 
 from astronomer.providers.amazon.aws.hooks.s3 import S3HookAsync
 
-log = logging.getLogger(__name__)
-
 
 class S3KeyTrigger(BaseTrigger):
     """
